@@ -14,7 +14,7 @@
 ##' }
 ##' Each combination of these variables (eg, full time, first time college students with an ed goal of degree/transfer as one combination) would constitute an iteration / sample for which to calculate disproportionate impact for outcomes listed in \code{success_vars} and for the disaggregation variables listed in \code{group_vars}. The overall rate of success for full time, first time college students with an ed goal of degree/transfer would just include these students and not others.  Each variable specified is also collapsed to an '- All' group so that the combinations also reflect all students of a particular category.  The total number of combinations for the previous example would be (+1 representing the all category): (3 + 1) x (2 + 1) x (2 + 1) = 36.
 ##' @param exclude_scenario_df (Optional) A data frame with variables that match \code{scenario_repeat_by_vars} for specifying the combinations to exclude from DI calculations.  Following the example specified above, one could choose to exclude part-time non-credit students from consideration.
-##' @param weight_var (Optional) A character variable specifying the weight variable if the input data set is summarized (ie,  the the success variables specified in \code{success_vars} contain count of successes).  Weight here corresponds to the denominator when calculating the success rate.  Defaults to \code{NULL} for an input data set where each row describes each individual.
+##' @param weight_var (Optional) A character variable specifying the weight variable if the input data set is summarized (i.e.,  the the success variables specified in \code{success_vars} contain count of successes).  Weight here corresponds to the denominator when calculating the success rate.  Defaults to \code{NULL} for an input data set where each row describes each individual.
 ##' @param include_non_disagg_results A logical variable specifying whether or not the non-disaggregated results should be returned; defaults to \code{TRUE}.  When \code{TRUE}, a new variable \code{`- None`} is added to the data set with a single data value \code{'- All'}, and this variable is added \code{group_vars} as a disaggregation/group variable.  The user would want these results returned to review non-disaggregated results.
 ##' @param ppg_reference_groups Either \code{'overall'}, \code{'hpg'}, \code{'all but current'}, or a character vector of the same length as \code{group_vars} that indicates the reference group value for each group variable in \code{group_vars} when determining disproportionate impact using the percentage point gap method.
 ##' @param min_moe The minimum margin of error to be used in the PPG calculation, passed to \link[DisImpact]{di_ppg}.
@@ -23,10 +23,10 @@
 ##' @param prop_sub_1 passed to \link[DisImpact]{di_ppg}; defaults to 0.50.
 ##' @param di_prop_index_cutoff Threshold used for determining disproportionate impact using the proportionality index; passed to \link[DisImpact]{di_prop_index}; defaults to 0.80.
 ##' @param di_80_index_cutoff Threshold used for determining disproportionate impact using the 80\% index; passed to \link[DisImpact]{di_80_index}; defaults to 0.80.
-##' @param di_80_index_reference_groups A character vector of the same length as \code{group_vars} that indicates the reference group value for each group variable in \code{group_vars} when determining disproportionate impact using the 80\% index; defaults to \code{'hpg'} (highest performing group as reference), but could also be \code{'overall'} or \code{'all but current'}.
+##' @param di_80_index_reference_groups Either \code{'overall'}, \code{'hpg'}, \code{'all but current'}, or a character vector of the same length as \code{group_vars} that indicates the reference group value for each group variable in \code{group_vars} when determining disproportionate impact using the 80\% index.
 ##' @param check_valid_reference Check whether \code{ppg_reference_groups} and \code{di_80_index_reference_groups} contain valid values; defaults to \code{TRUE}.
 ##' @param parallel If \code{TRUE}, then perform calculations in parallel based on the scenarios specified by \code{scenario_repeat_by_vars}.  Defaults to \code{FALSE}.  Parallel execution is based on the \code{parallel} package included in base R, using \link[parallel]{parLapply} on Windows and \link[parallel]{mclapply} on POSIX-based systems (Linux/Mac).
-##' @param parallel_n_cores The number of CPU cores to use if \code{parallel=TRUE}.  Defaults to the maximum number on the system.
+##' @param parallel_n_cores The number of CPU cores to use if \code{parallel=TRUE}.  Defaults to the maximum number CPU cores on the system.
 ##' @param parallel_split_to_disk If \code{TRUE} and \code{parallel=TRUE}, then create intermediate data sets for each scenario generated by \code{scenario_repeat_by_vars}, write them to disk, and import the required data set when necessary for each scenario executing in parallel.  This feature is useful when the data set specified by \code{data} is very large and parallel execution is desired for speed in order to reduce the likelihood of consuming all the system's memory and crashing.  Note that there is an overhead I/O cost on speed when this feature is used.  Defaults to \code{FALSE}.
 ##' @return A summarized data set (data frame) consisting of:
 ##' \itemize{
@@ -99,9 +99,9 @@ di_iterate <- function(data, success_vars, group_vars, cohort_vars=NULL, scenari
       ppg_reference_groups <- c(ppg_reference_groups, 'overall')
     } # else leave as is (overall, hpg, all but current to be used)
     if (length(di_80_index_reference_groups) > 1) {
-      di_80_index_reference_groups <- c(di_80_index_reference_groups, NA) # Adding last NA for non-disaggregated results
+      di_80_index_reference_groups <- c(di_80_index_reference_groups, 'overall')
     } else if (length(di_80_index_reference_groups) == 1 & !(is.na(di_80_index_reference_groups) | di_80_index_reference_groups %in% c('hpg', 'overall', 'all but current'))) {
-      di_80_index_reference_groups <- c(di_80_index_reference_groups, NA)
+      di_80_index_reference_groups <- c(di_80_index_reference_groups, 'overall')
     } # else leave as is (overall, hpg, all but current to be used)
   }
   
@@ -124,7 +124,7 @@ di_iterate <- function(data, success_vars, group_vars, cohort_vars=NULL, scenari
 
   if (is.null(cohort_vars)) {
     cohort_vars <- '_cohort_'
-    data[[cohort_vars]] <- '- All'
+    data[[cohort_vars]] <- ''
   } else {
     # Check valid cohort_vars
     for (i in seq_along(cohort_vars)) {
@@ -341,9 +341,15 @@ di_iterate <- function(data, success_vars, group_vars, cohort_vars=NULL, scenari
 
   # Iterate for all scenarios
   if (is.null(scenario_repeat_by_vars)) {
+    # CRAN: no visible binding for global variable
+    success_variable <- cohort_variable <- cohort <- disaggregation <- group <- NULL
+    
     subset_idx <- 1:nrow(data)
     pmap(dScenarios %>% mutate(subset_idx=list(subset_idx), parallel_split_to_disk=FALSE, split_filename='NOT_USED'), iterate) %>%
-      bind_rows
+      bind_rows %>%
+      mutate(cohort_variable=ifelse(cohort_variable=='_cohort_', '', cohort_variable)) %>% 
+      arrange(success_variable, cohort_variable, cohort, disaggregation, group) %>%
+      return()
   } else {
     if (!parallel) {
       dRepeatScenarios$df_results <- lapply(1:nrow(dRepeatScenarios)
@@ -404,10 +410,13 @@ di_iterate <- function(data, success_vars, group_vars, cohort_vars=NULL, scenari
     
     # CRAN: no visible binding for global variable
     df_results <- split_filename <- NULL
-    
+
     dRepeatScenarios %>%
       select(-want_indices, -parallel_split_to_disk, -split_filename) %>%
-      unnest(df_results)
+      unnest(df_results) %>%
+      mutate(cohort_variable=ifelse(cohort_variable=='_cohort_', '', cohort_variable)) %>% 
+      arrange(across(one_of(c(scenario_repeat_by_vars, 'success_variable', 'cohort_variable', 'cohort', 'disaggregation', 'group')))) %>%
+      return()
   }
 }
 
